Agent Kitchen

All time
`/` to search
Loading sessions...
No sessions found

Agent Kitchen looks for sessions in `~/.claude` and `~/.codex` directories.

Start a Claude Code or Codex CLI session in any git repo, then refresh this page.

You can also try increasing the scan range using the days input above.

Keyboard Shortcuts
`/`Search sessions
`?`Show this help
`r`Refresh sessions
`j`Next group
`k`Previous group
`Enter`Expand / collapse group
`Esc`Close terminal / overlay
Press `?` or `Esc` to close